TypeEncodeDecode class

Mixed-in types

Constructors

TypeEncodeDecode(LegacyBCS bcs, List<TypeName> generics, EncodeCb encodeCb, DecodeCb decodeCb, ValidateCb validateCb)

Properties

bcs LegacyBCS
final
decodeCb DecodeCb
final
encodeCb EncodeCb
final
generics List<TypeName>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validateCb ValidateCb
final

Methods

decode(Uint8List data, List<TypeName> typeParams) → dynamic
override
decodeRaw(BcsReader reader, List<TypeName> typeParams, Map<String, TypeName> typeMap) → dynamic
override
encode(dynamic data, BcsWriterOptions? options, List<TypeName> typeParams) BcsWriter
override
encodeRaw(BcsWriter writer, dynamic data, List<TypeName> typeParams, Map<String, TypeName> typeMap) BcsWriter
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited